MiniprinterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MiniprinterPlatform
Implementers

Constructors

MiniprinterPlatform()
Constructs a MiniprinterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() → Future<void>
disconnect() → Future<void>
getCurrentBattery() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print({required String image, required int copies}) → Future<void>
showNativeModal({required String message}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ MiniprinterPlatform
The default instance of MiniprinterPlatform to use.
getter/setter pair